--[[
************************************************************************
Project				: SKG
Author				: zhinjio
Project Revision	: r136
Project Date		: 20090202211706

File				: MainFrame.lua
Commit Author		: zhinjio
Commit Revision		: 136
Commit Date			: 20090202211706
************************************************************************
Description	:
	Creation routines and handlers for the main frame. Includes the
	button launchers for other frames as well. I want this to also hook
	into the modules (based on security) that will add additional
	launchers based on security level.
	
TODO		:

************************************************************************
(see bottom of file for changelog)
************************************************************************
--]]
local MODNAME = "SKG"
local FULLNAME = MODNAME
local SKG = LibStub( "AceAddon-3.0" ):GetAddon( MODNAME, "AceEvent-3.0" )
local L = LibStub:GetLibrary( "AceLocale-3.0" ):GetLocale( MODNAME )

local addon = SKG

-- Frame Creation stuff
function addon.MainFrame_Create()
	-- These variables are used for determining the size and state of some of the frames
	-- I may turn these into saved variables at some point, but for now, just leave 'em
	-- static
	local db = addon.db.profile.Options.General

	-- So yeah, I switched this around since the titleframe turned out to be the more
	-- appropriate anchor
	addon.MF_TitleFrame = addon.myCreateFrame( 
		"MF_TitleFrame", UIParent, 170, 60, true, true,
		"TOPLEFT", UIParent, "BOTTOMLEFT", 200, 600,
		true, "DIALOG", 1, "", "", "371408", 1, "D49359", 1 ) do
		addon.MF_TitleFrame:SetHitRectInsets( 2, 2, 2, 2 )
		addon.MF_TitleFrame:RegisterForDrag( "LeftButton" )
		addon.MF_TitleFrame:SetScript( "OnDragStart", function( this )
			local db = addon.db.profile.Options.General
			if ( db.locked ~= true ) then
				this:StartMoving()
			end
		end )
		addon.MF_TitleFrame:SetScript( "OnDragStop", function( this )
			local db = SKG.db.profile.Options.General
			if ( db.locked ~= true ) then
				this:StopMovingOrSizing()
				db.xPos = this:GetLeft()
				db.yPos = this:GetTop()
			end
		end )
		
		addon.MFT_SKG = addon.MF_TitleFrame:CreateFontString( "MFT_SKG", "OVERLAY", "GameFontHighlight" ) do
			addon.MFT_SKG:SetText( "Suicide Kings Geo" )
			addon.MFT_SKG:SetPoint( "TOP", addon.MF_TitleFrame, "TOP", 0, -5 )
			addon.MFT_SKG:SetHeight( 14 )
			addon.MFT_SKG:SetWidth( 160 ) end
		addon.MFT_version = addon.MF_TitleFrame:CreateFontString( "MFT_version", "OVERLAY", "GameFontNormal" ) do
			addon.MFT_version:SetText( L["Version : "] .. addon.version )
			addon.MFT_version:SetPoint( "TOP", addon.MF_TitleFrame, "TOP", 0, -20 )
			addon.MFT_version:SetHeight( 14 )
			addon.MFT_version:SetWidth( 160 ) end
		addon.MFT_securityLevel = addon.MF_TitleFrame:CreateFontString( "MFT_securityLevel", "OVERLAY", "GameFontNormal" ) do
			addon.MFT_securityLevel:SetText( L["Security Level : "] .. addon.SECURITY_LEVEL )
			addon.MFT_securityLevel:SetPoint( "TOP", addon.MF_TitleFrame, "TOP", 0, -35 )
			addon.MFT_securityLevel:SetHeight( 14 )
			addon.MFT_securityLevel:SetWidth( 160 ) end
		addon.MFT_lock = addon.myCreateButton(
			"MFT_lock", addon.MF_TitleFrame, 16, 16,
			"TOPRIGHT", addon.MF_TitleFrame, "TOPRIGHT", -5, -4, 
			"", "", "", "", "", 
			4, 0, 3 ) do
			addon.MFT_lock:SetScript( "OnClick", function ( this )
				if ( db.locked == true ) then
					db.locked = false
					addon.MF_TitleFrame:SetMovable( true )
					addon.MFT_lock.overlay:SetTexCoord( .25, .5, 0, 1 )
				else
					db.locked = true
					addon.MF_TitleFrame:SetMovable( false )
					addon.MFT_lock.overlay:SetTexCoord( 0, .25, 0, 1 )
				end
			end )
		end
	end
	
	addon.MainFrame = addon.myCreateFrame( 
		"MainFrame", addon.MF_TitleFrame, 200, ( ( db.numListLines * addon.LINE_HEIGHT ) + 48 ), true, false, 
		"TOP", addon.MF_TitleFrame, "BOTTOM", 0, 9,
		true, "DIALOG", 3, 
		"Interface\\WorldMap\\UI-WorldMap-Middle3", "Interface\\DialogFrame\\UI-DialogBox-Gold-Border",
		"B17D4F", 1, "FFFFFF", 1 )
	addon.reAnchorMF()
	
	addon.MF_toggleList = addon.myCreateButton(
		"MF_toggleList", addon.MF_TitleFrame, 24, 24,
		"TOPLEFT", addon.MainFrame, "TOPLEFT", 3, -3,
		"", "", "", "", L["TT_TOGGLE_LISTVIEW"],
		1, 2, 4 ) do
		if ( db.listviewVisible == true ) then
			addon.MF_toggleList.rotate = ( 2 * 90 )
			addon.MF_toggleList.tex:SetTexCoord(unpack(addon.angles[addon.MF_toggleList.rotate]))
			addon.MF_TitleFrame:SetHeight( 60 )
			addon.MainFrame:Show()
			addon.MF_toggleList:SetPoint( "TOPLEFT", addon.MainFrame, "TOPLEFT", 3, -3 )
		else
			addon.MF_toggleList.rotate = 0
			addon.MF_toggleList.tex:SetTexCoord(unpack(addon.angles[addon.MF_toggleList.rotate]))
			addon.MainFrame:Hide()
			addon.MF_TitleFrame:SetHeight( 55 )
			addon.MF_toggleList:SetPoint( "TOPLEFT", addon.MF_TitleFrame, "TOPLEFT", 2, -2 )
		end
		addon.MF_toggleList:SetScript( "OnClick", function ( this )
			if ( db.listviewVisible == true ) then
				this.rotate = 0
				this.tex:SetTexCoord(unpack(addon.angles[this.rotate]))
				addon.MF_TitleFrame:SetHeight( 55 )
				addon.MainFrame:Hide()
				this:SetPoint( "TOPLEFT", addon.MF_TitleFrame, "TOPLEFT", 2, -2 )
				db.listviewVisible = false
			else
				this.rotate = ( 2 * 90 )
				this.tex:SetTexCoord(unpack(addon.angles[this.rotate]))
				addon.MainFrame:Show()
				addon.MF_TitleFrame:SetHeight( 60 )
				this:SetPoint( "TOPLEFT", addon.MainFrame, "TOPLEFT", 3, -3 )
				db.listviewVisible = true
			end
		end )
	end
		
	addon.MF_ButtonTab = addon.myCreateFrame(
		"MF_ButtonTab", addon.MainFrame, 65, 290, true, false,
		"TOPLEFT", addon.MainFrame, "TOPRIGHT", -20, -1,
		false, "DIALOG", 1,
		"Interface\\AchievementFrame\\UI-Achievement-Parchment", "",
		"FFFFFF", 1, "D49359", 1 )
	
	addon.MF_expandBT = addon.myCreateButton(
		"MF_expandBT", addon.MainFrame, 24, 24,
		"TOPRIGHT", addon.MF_ButtonTab, "TOPRIGHT", -2, -2,
		"", "", "", "", L["TT_EXPAND_BUTTONTAB"],
		1, 3, 0 ) do
		if ( db.buttontabVisible == true ) then
			addon.MF_expandBT.rotate = ( 3 * 90 )
			addon.MF_expandBT.tex:SetTexCoord(unpack(addon.angles[addon.MF_expandBT.rotate]))
			addon.MF_ButtonTab:SetPoint( "TOPLEFT", addon.MainFrame, "TOPRIGHT", -20, -1 )
			addon.MF_expandBT:SetPoint( "TOPRIGHT", addon.MF_ButtonTab, "TOPRIGHT", -2, -2 )
		else
			addon.MF_expandBT.rotate = ( 1 * 90 )
			addon.MF_expandBT.tex:SetTexCoord(unpack(addon.angles[addon.MF_expandBT.rotate]))
			addon.MF_ButtonTab:SetPoint( "TOPLEFT", addon.MainFrame, "TOPRIGHT", -59, -1 )
			addon.MF_expandBT:SetPoint( "TOPRIGHT", addon.MF_ButtonTab, "TOPRIGHT", -8, -2 )
		end
		addon.MF_expandBT:SetScript( "OnClick", function ( this )
			if ( db.buttontabVisible == true ) then
				this.rotate = ( 1 * 90 )
				this.tex:SetTexCoord(unpack(addon.angles[this.rotate]))
				addon.MF_ButtonTab:SetPoint( "TOPLEFT", addon.MainFrame, "TOPRIGHT", -59, -1 )
				this:SetPoint( "TOPRIGHT", addon.MF_ButtonTab, "TOPRIGHT", -8, -2 )
				db.buttontabVisible = false
			else
				this.rotate = ( 3 * 90 )
				this.tex:SetTexCoord(unpack(addon.angles[this.rotate]))
				addon.MF_ButtonTab:SetPoint( "TOPLEFT", addon.MainFrame, "TOPRIGHT", -20, -1 )
				this:SetPoint( "TOPRIGHT", addon.MF_ButtonTab, "TOPRIGHT", -2, -2 )
				db.buttontabVisible = true
			end
		end )
	end
	
	addon.MF_addtolist = addon.myCreateButton(
		"MF_addtolist", addon.MainFrame, 16, 16,
		"BOTTOMLEFT", addon.MainFrame, "BOTTOMLEFT", 5, 5,
		"", "", "", "", L["TT_ADDTO_LISTVIEW"],
		2, 0, 0 ) do
		if ( db.numListLines > ( addon.MAX_LIST_LINES - 1 ) ) then
			db.numListLines = addon.MAX_LIST_LINES
			addon.MF_addtolist:Disable()
		end
		addon.MF_addtolist:SetScript( "OnClick", function()
			db.numListLines = db.numListLines + 1
			if ( db.numListLines > addon.MIN_LIST_LINES ) then
				addon.MF_delfromlist:Enable()
			end
			if ( db.numListLines > ( addon.MAX_LIST_LINES - 1 ) ) then
				db.numListLines = addon.MAX_LIST_LINES
				addon.MF_addtolist:Disable()
			end
			addon.MainFrame:SetHeight( ( ( db.numListLines * addon.LINE_HEIGHT ) + 48 ) )
			addon.MF_listview:SetHeight( ( db.numListLines * addon.LINE_HEIGHT ) )
--			db.yPos = db.yPos - addon.LINE_HEIGHT
--			addon.reAnchorMF()
		end )
	end
	addon.MF_delfromlist = addon.myCreateButton(
		"MF_delfromlist", addon.MainFrame, 16, 16,
		"BOTTOMRIGHT", addon.MainFrame, "BOTTOMRIGHT", -5, 5,
		"", "", "", "", L["TT_DELFROM_LISTVIEW"],
		3, 0, 0 ) do
		if ( db.numListLines < ( addon.MIN_LIST_LINES + 1 ) ) then
			db.numListLines = addon.MIN_LIST_LINES
			addon.MF_delfromlist:Disable()
		end
		addon.MF_delfromlist:SetScript( "OnClick", function()
			db.numListLines = db.numListLines - 1
			if ( db.numListLines < ( addon.MIN_LIST_LINES + 1 ) ) then
				db.numListLines = addon.MIN_LIST_LINES
				addon.MF_delfromlist:Disable()
			end
			if ( db.numListLines < ( addon.MAX_LIST_LINES ) ) then
				addon.MF_addtolist:Enable()
			end
			addon.MainFrame:SetHeight( ( ( db.numListLines * addon.LINE_HEIGHT ) + 48 ) )
			addon.MF_listview:SetHeight( ( db.numListLines * addon.LINE_HEIGHT ) )
--			db.yPos = db.yPos + addon.LINE_HEIGHT
--			addon.reAnchorMF()
		end )
	end
	
	addon.MF_listview = addon.myCreateFrame(
		"MF_listview", addon.MainFrame, 180, ( db.numListLines * addon.LINE_HEIGHT ), true, false,
		"TOP", addon.MainFrame, "TOP", 0, -26,
		false, "DIALOG", 4,
		"", "",
		"000000", .4, "000000", .8 )
	addon.MF_chooselist = addon.myCreateButton( 
		"MF_chooselist", addon.MainFrame, 21, 150,
		"TOP", addon.MainFrame, "TOP", 0, -4,
		"GameFontNormal", "GameFontHighlight", L["Choose List..."], "CENTER", L["TT_CHOOSELIST"],
		0, 0, 0 ) do
		addon.MF_chooselist:SetScript( "OnClick", function( this )
			
		end )
	end
	
end		
--[[
************************************************************************
CHANGELOG:

Date : 1/25/09
	Rewrite begins
************************************************************************
]]--