--[[
************************************************************************
Project				: SKG
Author				: zhinjio
Project Revision	: r136
Project Date		: 20090202211706

File				: SKG.lua
Commit Author		: zhinjio
Commit Revision		: 136
Commit Date			: 20090202211706
************************************************************************
Description	:
	Main addon primary methods (oninit, onenable, ondisable) and
	associated goo.

TODO		:
	Not sure why my timer frame code is in here. Is there maybe a better
	place for it?
************************************************************************
(see bottom of file for changelog)
************************************************************************
--]]

local MODNAME = "SKG"
local FULLNAME = MODNAME
local SKG = LibStub( "AceAddon-3.0" ):GetAddon( MODNAME, "AceEvent-3.0" )
local L = LibStub:GetLibrary( "AceLocale-3.0" ):GetLocale( MODNAME )
local AceConfig 		= LibStub("AceConfig-3.0")
local AceConfigReg 		= LibStub("AceConfigRegistry-3.0")
local AceConfigDialog 	= LibStub("AceConfigDialog-3.0")

local addon = SKG
-- addon globals
addon.me = ""
addon.version = "r136"
-- locals for this file
local db
local addonauthor = "zhinjio"
local builddate = "20090202211706"
-- Data Broker objects and functions
local LDB = LibStub( "LibDataBroker-1.1" )
local launcher = LDB:NewDataObject( MODNAME, {
	type = "data source",
	text = "",
	label = FULLNAME,
	icon = "Interface\\Addons\\" .. FULLNAME .. "\\icon",
	-- Right click gets you config, left click toggles main frame
	OnClick = function( clickedframe, button )
				if button == "RightButton" then
					addon:ShowConfig()
				else
					addon:Toggle()
				end
	end,
} )
-- keep out database in tip top shape
function addon.upgradeDB()
	local olddb = addon.db.profile
	if not olddb.Options.General.dbVersion then
		-- file existed before I added in db versioning. Do the right thing.
		olddb.Options.General.dbVersion = "1.0"
		addon.Print( string.format( L["Database upgraded to %s"], "1.0" ) )
	end
	if ( olddb.Options.General.dbVersion == "1.0" ) then
		olddb.Options.General.buttonTexture = nil
		olddb.Options.General.uiscale = 1
		olddb.Options.General.xPos = 100
		olddb.Options.General.yPos = -100
		olddb.firstLoad = nil
		olddb.Options.General.dbVersion = "1.1"
		addon.Print( string.format( L["Database upgraded to %s"], "1.1" ) )
	end
	if ( olddb.Options.General.dbVersion == "1.1" ) then
		olddb.Options.General.suppressload = false
		olddb.Options.General.dbVersion = "1.2"
		addon.Print( string.format( L["Database upgraded to %s"], "1.2" ) )
	end
	if ( olddb.Options.General.dbVersion == "1.2" ) then
		olddb.Options.General.buttontabVisible = true
		olddb.Options.General.listviewVisible = true
		olddb.Options.General.numListLines = 20
		olddb.Options.General.xPos = 200
		olddb.Options.General.yPos = 200
		olddb.Options.General.dbVersion = "1.3"
		addon.Print( string.format( L["Database upgraded to %s"], "1.3" ) )
	end
	if ( olddb.Options.General.dbVersion == "1.3" ) then
		olddb.Options.General.locked = false
		olddb.Options.General.dbVersion = "1.4"
		addon.Print( string.format( L["Database upgraded to %s"], "1.4" ) )
	end
end
-- options stuff
local options = nil
local displayOptions = nil
local modularOptions = {}
local function giveDisplay()
	if (not displayOptions) then
		displayOptions = {
			order = 2,
			type = "group",
			name = L["Display Options"],
			desc = L["DISPLAY_OPTIONS_DESC"],
			args = {
				header1 = {
					order	= 21,
					type	= "header",
					name	= L["Display Options"],
				},
				desc = {
					order	= 22,
					type	= "description",
					name	= L["DISPLAY_OPTIONS_DESC"],
				},
				sound = {
					order	= 23,
					type	= "toggle",
					name	= L["Enable DEBUG"],
					desc	= L["DISPLAY_DEBUG_DESC"],
					get		= function() return db.Options.General.debug end,
					set		= function() db.Options.General.debug = not db.Options.General.debug end,
				},
				uiscale = {
					order	= 24,
					type	= "range",
					name	= L["UI Scale"],
					desc	= L["UI_SCALE_DESC"],
					min		= .7,
					max		= 1.3,
					step	= .05,
					bigStep = .05,
					get		= function() return db.Options.General.uiscale end,
					set		= function( info, v ) 
								db.Options.General.uiscale = v
								addon.MF_TitleFrame:SetScale( v )
							  end,
				},
				autoopen = {
					order	= 25,
					type	= "toggle",
					name	= L["Toggle Auto-open"],
					desc	= L["TOGGLE_AUTOOPEN_DESC"],
					get		= function() return db.Options.General.autoopen end,
					set		= function() db.Options.General.autoopen = not db.Options.General.autoopen end,
				},
				classColors = {
					order	= 26,
					type	= "toggle",
					name	= L["Toggle Class Coloring"],
					desc	= L["TOGGLE_CLASSCOLOR_DESC"],
					get		= function() return db.Options.General.classColors end,
					set		= function() db.Options.General.classColors = not db.Options.General.classColors end,
				},
				raidonly = {
					order	= 27,
					type	= "toggle",
					name	= L["Toggle Raid Only View"],
					desc	= L["TOGGLE_RAIDONLY_DESC"],
					get		= function() return db.Options.General.raidonly end,
					set		= function() db.Options.General.raidonly = not db.Options.General.raidonly end,
				},
				suppressload = {
					order	= 28,
					type	= "toggle",
					name	= L["Suppress Load Message"],
					desc	= L["SUPPRESS_LOAD_DESC"],
					get		= function() return db.Options.General.suppressload end,
					set		= function() db.Options.General.suppressload = not db.Options.General.suppressload end,
				},
			},
		}
	end
	return displayOptions
end

local function fullOptions()
	if (not options) then
		options = {
			type = "group",
			name = MODNAME,
			args = {
				general = {
					order	= 1,
					type	= "group",
					name	= L["General Information"],
					desc	= L["GENERAL_INFO_DESC"],
					args	= {
						header1 = {
							order	= 11,
							type	= "header",
							name	= L["General Information"],
						},
						desc = {
							order	= 12,
							type	= "description",
							name	= L["GENERAL_INFO_DESC"],
						},
						author = {
							order	= 13,
							type	= "description",
							name	= L["Author : "] .. addonauthor .. "\n",
						},
						version = {
							order	= 14,
							type	= "description",
							name	= L["Version : "] .. addon.version .. "\n",
						},
						builddate = {
							order	= 15,
							type	= "description",
							name	= L["Build Date : "] .. builddate .. "\n",
						},
						dbversion = {
							order	= 15,
							type	= "description",
							name	= L["Database Version : "] .. db.Options.General.dbVersion .. "\n",
						},
						translators = {
							order	= 16,
							type	= "description",
							name	= string.format( L["Helpful Translators (thank you) : %s"], " \n" )
						},
					},
				},
			},
		}
	end
	
	for k,v in pairs(modularOptions) do
		options.args[k] = (type(v) == "function") and v() or v
	end

	return options
end

function addon:SetupOptions()
	AceConfigReg:RegisterOptionsTable(MODNAME, fullOptions)
	self.optionsFrame = AceConfigDialog:AddToBlizOptions(MODNAME, nil, nil, "general")

	-- Fill up our modular options...
	self:RegisterModuleOptions("Display", giveDisplay(), L["Display Options"])
end

function addon:RegisterModuleOptions(name, optionsTable, displayName)
	modularOptions[name] = optionsTable
	self.optionsFrame[name] = AceConfigDialog:AddToBlizOptions(MODNAME, displayName, MODNAME, name)
end

function addon:ShowConfig()
	-- Open the profiles tab before, so the menu expands
	InterfaceOptionsFrame_OpenToCategory( self.optionsFrame["Display"] )
end

function addon:Toggle()
	if ( addon.IsEnabled == true ) then
		if ( addon.MF_TitleFrame:IsVisible() ) then
			addon.MF_TitleFrame:Hide()
		else
			addon.MF_TitleFrame:Show()
		end
	else
		addon.Print( L["SKG is not enabled."] )
	end
end

function addon:OnInitialize()
end

function addon:OnEnable()
	addon.IsEnabled = true
	addon.me = UnitName( "player" )
	-- Get us our saved variables
	self.db = LibStub( "AceDB-3.0" ):New( MODNAME .. "_DB", nil, "Default" )
	-- if this toon doesn't have any info, set us up
	if not ( self.db.profile ) then
		sdbp = self.db.profile
		sdbp.Players = {}
		sdbp.Alts = {}
		sdbp.RollLists = {}
		sdbp.LastMod = {}
		sdbp.Log = {
			["SKG"] = {},
			["Loot"] = {},
		}
		sdbp.Snapshot = {}
		sdbp.SnapshotLM = {}
		sdbp.Options = {
			General = {
				debug = false,
				autoopen = false,
				classColors = true,
				raidonly = false,
				suppressload = false,
				buttontabVisible = true,
				listviewVisible = true,
				numListLines = 20,
				locked = false,
				xPos = 200,
				yPos = 200,
				dbVersion = "1.4",
				uiscale = 1,
			},
			Security = {
				Policies = {},
			},
			Bid = {
				ArmorFilter = 0,
			},
			List = {},
		}
	else
		-- we do have info, make sure the database spec is current
		addon.upgradeDB()
	end
	db = self.db.profile
	-- Setup the blizzard options frame stuff for this addon
	addon:SetupOptions()
	-- Previously, I had all the create frames stuff here, to init the addon
	-- I realized that I can't really "properly" initialize until I can see
	-- guild roster information.
	--
	-- So I'm moving all the real initialize stuff to the events handler for
	-- GUILD_ROSTER_UPDATE
	addon:RegisterEvent( "GUILD_ROSTER_UPDATE" )
end

function addon:OnDisable()
	if ( addon.IsEnabled == true ) then
		addon:UnregisterChatCommand( "skg" )
		addon:UnregisterAllEvents()
		addon:UnregisterComm( MODNAME )
		addon.MainFrame:Hide()
		addon.Print( "Addon Disabled." )
		addon.IsEnabled = false
	end
end

function addon:Disable()
	if ( addon.IsEnabled == true ) then
		addon:UnregisterChatCommand( "skg" )
		addon:UnregisterAllEvents()
		addon:UnregisterComm( MODNAME )
		addon.MainFrame:Hide()
		addon.Print( "Addon Disabled." )
		addon.IsEnabled = false
	end
end

-- Slash command handler
function addon:OnSlashCommand( text )
	if ( text == "" ) then
		--[[
		if ( SKG_Frame:IsVisible() ) then
			PlaySound("igMainMenuClose");
			SKG_Frame:Hide()
		else
			PlaySound("igMainMenuOpen");
			SKG_Frame:Show()
		end
		]]--
	elseif ( text == "reset" ) then
		db.Options.General.xPos = 100
		db.Options.General.yPos = -100
		-- SKG_Frame:SetPoint( "TOPLEFT", UIParent, "TOPLEFT", 100, -100 )
		-- SKG_Frame:Show()
	elseif ( text == "checklists" ) then
		-- These commands should only work if you're a syncer (or above) 
		if ( SKG_SECURITY_LEVEL ~= "U" ) then
			addon.Print( L["SKG_MSG_DIAG"] )
			-- perform a diagnostic check on lists to see if they have corruption
			-- Check Players list
			--[[
			local rc = SKG_checkList( "Players" )
			SKG_Print( SKG_ListError( "Players", rc ) )
			-- Check Alts list
			rc = SKG_checkList( "Alts" )
			SKG_Print( SKG_ListError( "Alts", rc ) )
			-- loop through the rolling lists
			local db = SKG.db.profile.RollLists
			for k, v in pairs( db ) do
				rc = SKG_checkList( k )
				SKG_Print( SKG_ListError( k, rc ) )
			end
			]]--
			addon.Print( L["SKG_MSG_DIAGCOMPLETE"] )
		else
			addon.Print( L["SKG_ERROR_NOTLEET"] )
		end
	elseif ( text == "repairlists" ) then
		-- make an attempt to get rid of bad entries in lists
		if ( SKG_SECURITY_LEVEL ~= "U" ) then
			addon.Print( L["SKG_MSG_LISTREPAIR"] )
			-- SKG_RepairLists()
			addon.Print( L["SKG_MSG_REPAIRCOMPLETE"] )
		else
			addon.Print( L["SKG_ERROR_NOTLEET"] )
		end
	else
		addon.Print( L["SKG Usage:"] )
		addon.Print( "  " .. L["/skg - open SKG GUI"] )
		addon.Print( "  " .. L["/skg reset - reset SKG GUI position"] )
		addon.Print( "  " .. L["/skg checklists - check lists for corruption"] )
		addon.Print( "  " .. L["/skg repairlists - attempt to repair list corruption"] )
	end
end

--[[
************************************************************************
CHANGELOG:

Date : 1/25/09
	Rewrite
Date : 10/26/08
	Moving RegisterEvent calls to OnInit
	Moving RegisterComm call to OnInit
	Defined fubarOptionsTable to be global
Date : 10/21/08
	Initial attempt with Ace3 instead of LibRock. Probably will require
	major edits once. Added header/footer.
************************************************************************
]]--